@@ -3,8 +3,8 @@
     Pygments HTML formatter tests
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-    :copyright: 2006-2007 by Georg Brandl.
-    :license: BSD, see LICENSE for more details.
+    :copyright: Copyright 2006-2009 by the Pygments team, see AUTHORS.
+    :license: BSD, see LICENSE for details.
 """
 
 import os
@@ -12,14 +12,17 @@ import re
 import unittest
 import StringIO
 import tempfile
-from os.path import join, dirname, isfile
+from os.path import join, dirname, isfile, abspath
 
 from pygments.lexers import PythonLexer
 from pygments.formatters import HtmlFormatter, NullFormatter
 from pygments.formatters.html import escape_html
 
-tokensource = list(PythonLexer().get_tokens(file(
-    os.path.join(testdir, testfile)).read()))
+import support
+
+TESTFILE, TESTDIR = support.location(__file__)
+
+tokensource = list(PythonLexer(encoding='utf-8').get_tokens(open(TESTFILE).read()))
 
 class HtmlFormatterTest(unittest.TestCase):
     def test_correct_output(self):
@@ -38,23 +41,24 @@ class HtmlFormatterTest(unittest.TestCase):
     def test_external_css(self):
         # test correct behavior
         # CSS should be in /tmp directory
-        fmt1 = HtmlFormatter(full=True, cssfile='fmt1.css')
-        # CSS should be in testdir (testdir is absolute)
-        fmt2 = HtmlFormatter(full=True, cssfile=join(testdir, 'fmt2.css'))
+        fmt1 = HtmlFormatter(full=True, cssfile='fmt1.css', outencoding='utf-8')
+        # CSS should be in TESTDIR (TESTDIR is absolute)
+        fmt2 = HtmlFormatter(full=True, cssfile=join(TESTDIR, 'fmt2.css'),
+                             outencoding='utf-8')
         tfile = tempfile.NamedTemporaryFile(suffix='.html')
         fmt1.format(tokensource, tfile)
         try:
             fmt2.format(tokensource, tfile)
+            self.assert_(isfile(join(TESTDIR, 'fmt2.css')))
         except IOError:
             # test directory not writable
             pass
         tfile.close()
 
-        self.assert_(isfile(join(dirname(tfile.name), 'my.css')))
-
+        self.assert_(isfile(join(dirname(tfile.name), 'fmt1.css')))
         os.unlink(join(dirname(tfile.name), 'fmt1.css'))
         try:
-            os.unlink(join(testdir, 'fmt2.css'))
+            os.unlink(join(TESTDIR, 'fmt2.css'))
         except OSError:
             pass
 
@@ -70,13 +74,14 @@ class HtmlFormatterTest(unittest.TestCase):
 
     def test_valid_output(self):
         # test all available wrappers
-        fmt = HtmlFormatter(full=True, linenos=True, noclasses=True)
+        fmt = HtmlFormatter(full=True, linenos=True, noclasses=True,
+                            outencoding='utf-8')
 
         handle, pathname = tempfile.mkstemp('.html')
         tfile = os.fdopen(handle, 'w+b')
         fmt.format(tokensource, tfile)
         tfile.close()
-        catname = os.path.join(testdir, 'dtds', 'HTML4.soc')
+        catname = os.path.join(TESTDIR, 'dtds', 'HTML4.soc')
         try:
             try:
                 import subprocess
@@ -87,9 +92,33 @@ class HtmlFormatterTest(unittest.TestCase):
                 ret = os.popen('nsgmls -s -c "%s" "%s"' % (catname, pathname)).close()
                 if ret == 32512: raise OSError  # not found
         except OSError:
-            # latex not available
+            # nsgmls not available
             pass
         else:
             self.failIf(ret, 'nsgmls run reported errors')
 
         os.unlink(pathname)
+
+    def test_get_style_defs(self):
+        fmt = HtmlFormatter()
+        sd = fmt.get_style_defs()
+        self.assert_(sd.startswith('.'))
+
+        fmt = HtmlFormatter(cssclass='foo')
+        sd = fmt.get_style_defs()
+        self.assert_(sd.startswith('.foo'))
+        sd = fmt.get_style_defs('.bar')
+        self.assert_(sd.startswith('.bar'))
+        sd = fmt.get_style_defs(['.bar', '.baz'])
+        fl = sd.splitlines()[0]
+        self.assert_('.bar' in fl and '.baz' in fl)
+
+    def test_unicode_options(self):
+        fmt = HtmlFormatter(title=u'Föö',
+                            cssclass=u'bär',
+                            cssstyles=u'div:before { content: \'bäz\' }',
+                            encoding='utf-8')
+        handle, pathname = tempfile.mkstemp('.html')
+        tfile = os.fdopen(handle, 'w+b')
+        fmt.format(tokensource, tfile)
+        tfile.close()
